package org.rcisoft.baidu.censor.config;

import com.baidu.aip.contentcensor.AipContentCensor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class ContentCensorClientConfig {
    /**
     * 百度云审核的AppID
     */
    @Value("${censor.appId}")
    String appId;
    /**
     * 百度云审核的Api Key
     */
    @Value("${censor.apiKey}")
    String apiKey;
    /**
     * 百度云审核的Secret Key
     */
    @Value("${censor.secretKey}")
    String secretKey;

    @Bean(name = "commonTextCensorClient")
    AipContentCensor commonTextCensorClient() {
        /**
         * 可以选择在客户端中添加参数，参考 https://ai.baidu.com/ai-doc/ANTIPORN/ik3h6xdze
         * 如：
         *         // 可选：设置网络连接参数
         *         client.setConnectionTimeoutInMillis(2000);
         *         client.setSocketTimeoutInMillis(60000);
         *
         *         // 可选：设置代理服务器地址, http和socket二选一，或者均不设置
         *         client.setHttpProxy("proxy_host", proxy_port);  // 设置http代理
         *         client.setSocketProxy("proxy_host", proxy_port);  // 设置socket代理
         *
         *         // 可选：设置log4j日志输出格式，若不设置，则使用默认配置
         *         // 也可以直接通过jvm启动参数设置此环境变量
         *         System.setProperty("aip.log4j.conf", "path/to/your/log4j.properties");
         */
        return new AipContentCensor(appId, apiKey, secretKey);
    }
}

