package org.rcisoft.business.opmArticleCommentMessageError.service.impl;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.business.opmArticleCommentMessageError.dao.OpmArticleCommentMessageErrorRepository;
import org.rcisoft.business.opmArticleCommentMessageError.entity.OpmArticleCommentMessageError;
import org.rcisoft.business.opmArticleCommentMessageError.service.OpmArticleCommentMessageErrorService;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2025年4月27日 下午3:36:30.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class OpmArticleCommentMessageErrorServiceImpl extends ServiceImpl<OpmArticleCommentMessageErrorRepository, OpmArticleCommentMessageError> implements OpmArticleCommentMessageErrorService {


    /**
    * 保存 动态/评论/留言错误表
    * @param opmArticleCommentMessageError
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(OpmArticleCommentMessageError opmArticleCommentMessageError){
        //增加操作
        int line = baseMapper.insert(opmArticleCommentMessageError);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            opmArticleCommentMessageError.getBusinessId()+"的动态/评论/留言错误表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 动态/评论/留言错误表
    * @param opmArticleCommentMessageError
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(OpmArticleCommentMessageError opmArticleCommentMessageError){
        int line = baseMapper.realDelete(opmArticleCommentMessageError);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            opmArticleCommentMessageError.getBusinessId()+"的动态/评论/留言错误表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 动态/评论/留言错误表
    * @param opmArticleCommentMessageError
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(OpmArticleCommentMessageError opmArticleCommentMessageError){
        opmArticleCommentMessageError.setDeleted();
        int line = baseMapper.deleteById(opmArticleCommentMessageError);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                opmArticleCommentMessageError.getBusinessId()+"的动态/评论/留言错误表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 动态/评论/留言错误表
    * @param opmArticleCommentMessageError
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(OpmArticleCommentMessageError opmArticleCommentMessageError){
        int line = baseMapper.updateById(opmArticleCommentMessageError);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ opmArticleCommentMessageError.getBusinessId()+"的动态/评论/留言错误表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 动态/评论/留言错误表
    * @param id
    * @return
    */
    @Override
    public OpmArticleCommentMessageError findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 动态/评论/留言错误表
    * @param opmArticleCommentMessageError
    * @return
    */
    @Override
    public IPage<OpmArticleCommentMessageError> findAllByPagination(CyPageInfo<OpmArticleCommentMessageError> paginationUtility,
                                                                    OpmArticleCommentMessageError opmArticleCommentMessageError){
        return baseMapper.queryOpmArticleCommentMessageErrorsPaged(paginationUtility,opmArticleCommentMessageError);

    }

    /**
    * 查询list 动态/评论/留言错误表
    * @param opmArticleCommentMessageError
    * @return
    */
    @Override
    public List<OpmArticleCommentMessageError> findAll(OpmArticleCommentMessageError opmArticleCommentMessageError){
        return baseMapper.queryOpmArticleCommentMessageErrors(opmArticleCommentMessageError);

    }

    /**
    * 导出动态/评论/留言错误表
    * @return
    */
    @Override
    public List<OpmArticleCommentMessageError> export(OpmArticleCommentMessageError opmArticleCommentMessageError) {
        List<OpmArticleCommentMessageError> opmArticleCommentMessageErrorList = baseMapper.queryOpmArticleCommentMessageErrors(opmArticleCommentMessageError);
        return opmArticleCommentMessageErrorList;
    }

}
