package org.rcisoft.business.opmBlacklist.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang.StringUtils;
import org.rcisoft.business.memInfo.dao.MemInfoRepository;
import org.rcisoft.business.memInfo.entity.MemFollowDTO;
import org.rcisoft.business.memLeaveMessage.dao.MemLeaveMessageRepository;
import org.rcisoft.business.memLeaveMessage.entity.MemLeaveMessage;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.opmBlacklist.dao.OpmBlackListRepository;
import org.rcisoft.business.opmBlacklist.entity.OpmBlackList;
import org.rcisoft.business.opmBlacklist.service.OpmBlackListService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.math.BigInteger;
import java.util.Date;
import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2025年2月10日 上午9:46:37.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class OpmBlackListServiceImpl extends ServiceImpl<OpmBlackListRepository,OpmBlackList>  implements OpmBlackListService {

    @Autowired
    private MemLeaveMessageRepository memLeaveMessageRepository;

    @Autowired
    private MemInfoRepository memInfoRepository;

    /**
    * 保存 黑名单表
    * @param opmBlackList
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(OpmBlackList opmBlackList){
        //增加操作
        Integer userId = Integer.valueOf(CyUserUtil.getAuthenBusinessId());
        opmBlackList.setUserId(BigInteger.valueOf(userId));
        opmBlackList.setCreateDate(new Date());
        int line = baseMapper.insert(opmBlackList);
        //添加到对话表设置拉黑用户
        //判断是否对方已将自己拉黑，如果对方也拉黑了，则直接删除这条对话
        Integer targetId = opmBlackList.getTargetId().intValue();
        MemLeaveMessage userTalk = memLeaveMessageRepository.queryUserTalk(userId, targetId);
        if (userTalk.getBlackUser() != 0){
            //对方也将自己拉黑了 则修改该条对话状态为-1
            userTalk.setBlackUser(-1);
            memLeaveMessageRepository.updateTalkBlack(userTalk);
        } else {
            //对方没将自己拉黑
            userTalk.setBlackUser(userId);
            memLeaveMessageRepository.updateTalkBlack(userTalk);
        }
        //取消当前用户对该用户的关注
        MemFollowDTO memFollowDTO = new MemFollowDTO();
        memFollowDTO.setUserId(userId);
        memFollowDTO.setTargetId(targetId);
        memInfoRepository.deleteFollow(memFollowDTO);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            opmBlackList.getBusinessId()+"的黑名单表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 黑名单表
    * @param opmBlackList
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(OpmBlackList opmBlackList){
        //删除黑名单
        int line = baseMapper.realDelete(opmBlackList);
        //修改对话表 拉黑状态
        MemLeaveMessage userTalk = memLeaveMessageRepository.queryUserTalk(opmBlackList.getUserId().intValue(), opmBlackList.getTargetId().intValue());
        if (userTalk != null && userTalk.getBlackUser() == opmBlackList.getUserId().intValue()) {
            //当前登录人拉黑了对方 修改对话状态为互相都没拉黑的情况
            userTalk.setBlackUser(0);
            memLeaveMessageRepository.updateTalkBlack(userTalk);
            return new CyPersistModel(line);
        } else if (userTalk != null && userTalk.getBlackUser() == -1){
            //对方也把自己拉黑了，双方都拉黑的情况
            userTalk.setBlackUser(opmBlackList.getTargetId().intValue());
            memLeaveMessageRepository.updateTalkBlack(userTalk);
            return new CyPersistModel(line);
        }
        return new CyPersistModel(1);
    }

    /**
    * 修改 黑名单表
    * @param opmBlackList
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(OpmBlackList opmBlackList){
        int line = baseMapper.updateById(opmBlackList);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ opmBlackList.getBusinessId()+"的黑名单表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 黑名单表
    * @param id
    * @return
    */
    @Override
    public OpmBlackList findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 黑名单表
    * @param opmBlackList
    * @return
    */
    @Override
    public IPage<OpmBlackList> findAllByPagination(CyPageInfo<OpmBlackList> paginationUtility,
        OpmBlackList opmBlackList){
        String userId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isNotEmpty(userId) && userId.equals("1")){
            //超级管理员
            return baseMapper.adminQueryOpmBlackListsPaged(paginationUtility,opmBlackList);
        } else {
            //普通用户
           opmBlackList.setUserId(BigInteger.valueOf(Integer.valueOf(userId)));
           return baseMapper.queryOpmBlackListsPaged(paginationUtility,opmBlackList);
        }
    }

    /**
    * 查询list 黑名单表
    * @param opmBlackList
    * @return
    */
    @Override
    public List<OpmBlackList> findAll(OpmBlackList opmBlackList){
        return baseMapper.queryOpmBlackLists(opmBlackList);

    }

    /**
    * 导出黑名单表
    * @return
    */
    @Override
    public List<OpmBlackList> export(OpmBlackList opmBlackList) {
        List<OpmBlackList> opmBlackListList = baseMapper.queryOpmBlackLists(opmBlackList);
        return opmBlackListList;
    }

}
