package org.rcisoft.core.schedule;

import lombok.extern.slf4j.Slf4j;
import org.jdom.JDOMException;
import org.rcisoft.business.cmsOrder.service.impl.CmsOrderServiceImpl;
import org.rcisoft.business.memInfo.bean.MemberInfoRedisBean;
import org.rcisoft.business.memInfo.dao.MemInfoRepository;
import org.rcisoft.business.memInfo.entity.MemLikeDTO;
import org.rcisoft.business.memInfo.service.MemInfoService;
import org.rcisoft.business.memInfo.service.impl.MemInfoServiceImpl;
import org.rcisoft.business.memLeaveMessage.service.impl.MemLeaveMessageServiceImpl;
import org.rcisoft.business.memTraffic.service.MemTrafficService;
import org.rcisoft.business.memTraffic.service.impl.MemTrafficServiceImpl;
import org.rcisoft.business.opmTopic.service.impl.OpmTopicServiceImpl;
import org.rcisoft.core.service.CyRedisService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.util.Map;
import java.util.Set;

@Component
@Slf4j
@EnableScheduling
public class ScheduleTasks {

   @Autowired
   private MemInfoServiceImpl memInfoService;
   @Autowired
   private CmsOrderServiceImpl orderService;
   @Autowired
   private MemLeaveMessageServiceImpl memLeaveMessageService;
   @Autowired
   private MemTrafficServiceImpl memTrafficService;
   @Autowired
   private OpmTopicServiceImpl opmTopicServiceImpl;

    /**
     * redis订单落库
     */
    @Scheduled(cron = "0 0/1 * * * ?")
    public void executeInsertOrder() throws NoSuchAlgorithmException {
        orderService.executeInsertOrder();
    }

    /**
     * redis订单关闭
     */
    @Scheduled(cron = "0 0/1 * * * ?")
    public void executeCloseOrder() throws NoSuchAlgorithmException {
        orderService.executeCloseOrder();
    }


    /**
     * 支付确认补救
     */
    @Scheduled(cron = "0 0/15 * * * ?")
    public void executePayOrder() throws IOException, JDOMException {
        orderService.executePayOrder();
    }

    /**
     * 退款接口调用补救
     */
    @Scheduled(cron = "0 0/30 * * * ?")
    public void executeRefundOrder() {
        orderService.executeRefundOrder();
    }

    /**
     * 退款确认补救
     */
    @Scheduled(cron = "0 0/30 * * * ?")
    public void executeRefundConfirmOrder() throws IOException, JDOMException {
        orderService.executeRefundConfirmOrder();
    }

    /**
     * 订单缓存清除
     */
    @Scheduled(cron = "0 0 1 * * ?")
    public void executeDeleteOrder() {
        orderService.executeDeleteOrder();
    }


    /**
     * 定时更新访问量表
     */
    @Scheduled(cron = "0 0/15 * * * ?")
    public void memTrafficSchedule() {
        memTrafficService.memTrafficSchedule();
    }

    /**
     * 定时更新话题表  刷新话题表的动态数
     * 每俩小时执行一次
     */
    @Scheduled(cron = "0 0 */2 * * ?")
    public void opmTopicSchedule() {
        opmTopicServiceImpl.opmTopicSchedule();
    }

    /**
     * 定时更新会员表  刷新会员的被关注数和被点赞数
     * 每2小时执行一次
     */
    @Scheduled(cron = "0 0 */2 * * ?")
    public void refreshMemLikeAndFollowCountSchedule() { memInfoService.refreshMemLikeAndFollowCountSchedule(); }

    /**
     * 定时更新会员表  更新会员的恶意留言次数
     * 每天凌晨1点执行一次
     */
    @Scheduled(cron = "0 0 1 * * ?")
    public void refreshMemMaliceLeaveCountSchedule() { memInfoService.refreshMemMaliceLeaveCountSchedule(); }
}
