package org.rcisoft.core.util;

import jakarta.servlet.http.HttpServletRequest;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.alibaba.faceVerify.bean.FaceVerifyRedisBean;
import org.rcisoft.business.memInfo.dao.MemInfoRepository;
import org.rcisoft.business.memInfo.entity.MemInfo;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.service.impl.CyRedisServiceImpl;
import org.rcisoft.sys.dictionary.entity.DictData;
import org.rcisoft.sys.dictionary.service.DictionaryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;

import javax.persistence.criteria.CriteriaBuilder;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.Random;

@Configuration
public class UserUtil {
    @Autowired
    MemInfoRepository memInfoRepository;

    @Autowired
    private DictionaryService dictionaryService;
    @Autowired
    private DictionaryUtil dictionaryUtil;
    @Autowired
    private CyRedisServiceImpl cyRedisServiceImpl;
    @Value("${forbidSpeech.oneHourCount}")
    private Integer oneHourCount;
    @Value("${forbidSpeech.oneHourTime}")
    private Integer oneHourTime;
    @Value("${forbidSpeech.twoHourCount}")
    private Integer twoHourCount;
    @Value("${forbidSpeech.twoHourTime}")
    private Integer twoHourTime;
    /**
     * 校验当前登录人是否已实名
     */
    public void checkUserAuth(String userId){
        // 查询数据字典 判断是否需要实名
        List<DictData> sysConfig = dictionaryService.selectByTypes("sys_config");
        DictData dictData = dictionaryUtil.getDictValue(sysConfig, "is_need_realAuth");
        String isRealAuthFlag = dictData.getDictValue();//是否需要实名认证  1：需要  0：不需要
        //添加实名判断
        if (isRealAuthFlag.equals("1")){
            MemInfo memInfo = memInfoRepository.getInfoByUserId(userId);
            if (!"1".equals(memInfo.getMemRealAuthen())){
                throw new CyServiceException("请先实名认证!");
            }
        }
    }


    /**
     *  校验用户是否已被禁言
     */
    public void checkUserForbidSpeech(String userId){
        //获取当前日期 例2025/2/20 获取02和20
        LocalDate today = LocalDate.now();
        DateTimeFormatter monthFormatter = DateTimeFormatter.ofPattern("MM");
        DateTimeFormatter dayFormatter = DateTimeFormatter.ofPattern("dd");
        // 格式化并获取月份和日期
        String month = today.format(monthFormatter);
        String day = today.format(dayFormatter);
        String date = month + day;
        Object timeFlag = cyRedisServiceImpl.hget("user:forbidSpeech:" + date + ":timeFlag",userId);
        if (timeFlag != null){
            // 获取当前时间毫秒值
            long currentTimeMillis = System.currentTimeMillis();
            if ((long)timeFlag >= currentTimeMillis){
               throw new CyServiceException(1008,"您已被禁言，请稍后再试!");
            }
        }
    }

    /**
     *  设置用户禁言
     */
    public void setUserForbidSpeech(String userId){
        //获取当前日期 例2025/2/20 获取02和20
        LocalDate today = LocalDate.now();
        DateTimeFormatter monthFormatter = DateTimeFormatter.ofPattern("MM");
        DateTimeFormatter dayFormatter = DateTimeFormatter.ofPattern("dd");
        // 格式化并获取月份和日期
        String month = today.format(monthFormatter);
        String day = today.format(dayFormatter);
        String date = month + day;
        // 获取当前时间 年月日时分秒
        long currentTime = System.currentTimeMillis();
        Object redisOneHourCount = cyRedisServiceImpl.get("user:forbidSpeech:" + date + ":oneHourCount:" + userId);
        Object redisTwoHourCount = cyRedisServiceImpl.get("user:forbidSpeech:" + date + ":twoHourCount:" + userId);
        Object redisAllCount = cyRedisServiceImpl.get("user:forbidSpeech:" + date + ":allCount:" + userId);
        if (redisOneHourCount == null && redisTwoHourCount == null){
            // 2小时内没有被自动驳回过 设置初始值1
            cyRedisServiceImpl.set("user:forbidSpeech:" + date + ":oneHourCount:" + userId,1, 1*60*60L);
            cyRedisServiceImpl.set("user:forbidSpeech:" + date + ":twoHourCount:" + userId,1, 2*60*60L);
            if (redisAllCount != null){
                cyRedisServiceImpl.incr("user:forbidSpeech:" + date + ":allCount:" + userId,1L);
            } else {
                cyRedisServiceImpl.set("user:forbidSpeech:" + date + ":allCount:" + userId,1,24*60*60L);
            }
        } else if (redisOneHourCount == null && redisTwoHourCount != null){
            // 2小时内被自动驳回过
            if ((int)redisTwoHourCount >= twoHourCount){
                // 2小时内被驳回数大于限制数 禁言一天 设置过期时间为2天
                cyRedisServiceImpl.hset("user:forbidSpeech:" + date + ":timeFlag",userId, currentTime + twoHourTime*1000);
                // 设置键的过期时间为2天，单位是秒，所以2天等于172800秒
                cyRedisServiceImpl.expire("user:forbidSpeech:" + date + ":timeFlag", 172800L);
            } else {
                cyRedisServiceImpl.set("user:forbidSpeech:" + date + ":oneHourCount:" + userId,1, 1*60*60L);
                cyRedisServiceImpl.incr("user:forbidSpeech:" + date + ":twoHourCount:" + userId, 1L);
                cyRedisServiceImpl.incr("user:forbidSpeech:" + date + ":allCount:" + userId,1L);
            }
        } else {
            // 1小时内被驳回过
            if ((int)redisOneHourCount >= oneHourCount){
                //1小时内被驳回数大于限制数 禁言1小时
                cyRedisServiceImpl.hset("user:forbidSpeech:" + date + ":timeFlag",userId, currentTime + oneHourTime*1000);
            } else {
                cyRedisServiceImpl.incr("user:forbidSpeech:" + date + ":oneHourCount:" + userId, 1L);
                cyRedisServiceImpl.incr("user:forbidSpeech:" + date + ":twoHourCount:" + userId, 1L);
                cyRedisServiceImpl.incr("user:forbidSpeech:" + date + ":allCount:" + userId,1L);
            }
        }
    }
}
